@@ -431,8 +431,8 @@ install_SL(){
   # Program file might give different results:
   # ISO 9660 CD-ROM filesystem data # file vesion 5.03
   # x86 boot sector # file version 4.10
-  if [ -z "$(LC_ALL=C file -L $SL_ISO | grep -i "ISO 9660 CD-ROM filesystem data")" ] && \
-     [ -z "$(LC_ALL=C file -L $SL_ISO | grep -i "x86 boot sector")" -a "$(echo $SL_ISO | grep -iE "\.iso")" ]; then
+  if [ -z "$(LC_ALL=C file -Ls $SL_ISO | grep -i "ISO 9660 CD-ROM filesystem data")" ] && \
+     [ -z "$(LC_ALL=C file -Ls $SL_ISO | grep -i "x86 boot sector")" -a "$(echo $SL_ISO | grep -iE "\.iso")" ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
     echo "$SL_ISO is not an ISO 9660 CD-ROM filesystem data file!"
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
@@ -555,10 +555,10 @@ install_SL(){
     # For old file, like Debian Sarge (file 4.12-1) or RH9 (file-3.39-9):
     # In Debian Sarge: vmlinuz-2.6.8-2-686: x86 boot sector
     # In RH9: vmlinuz-2.4.20-28.9smp: x86 boot sector
-    if [ -n "$(file $i | grep -iE "(Linux x86 kernel|Linux kernel x86 boot executable|x86 boot sector)")" ]; then
+    if [ -n "$(LC_ALL=C file -Ls $i | grep -iE "(Linux x86 kernel|Linux kernel x86 boot executable|x86 boot sector)")" ]; then
       # Ugly
       # we skip memtest, etherboot, freedos...
-      if [ -z "$(echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn|ipxe.lkn|freedos|fdos)")" ]; then
+      if [ -z "$(LC_ALL=C echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn|ipxe.lkn|freedos|fdos)")" ]; then
         kernel="$i"
         break
       fi
@@ -577,12 +577,12 @@ install_SL(){
   # Find initrd
   # UGLY! Here we assume only one gzip/cpio file exists, and it's initrd.
   for i in $isomnt/$bootfiles_path/* $isomnt/$rootfile_path/*; do
-    if [ -n "$(file $i | grep -i "gzip compressed data")" ]; then
+    if [ -n "$(LC_ALL=C file -Ls $i | grep -iE "(gzip compressed data|XZ compressed data)")" ]; then
       oldinitrd="$i"
       uncompress_to_stdout="gunzip -c"
       compress_to_stdout="gzip -c"
       break
-    elif [ -n "$(echo $i | grep -iE "\/miniroot.lz$")" ]; then
+    elif [ -n "$(LC_ALL=C echo $i | grep -iE "\/miniroot.lz$")" ]; then
     # For INSERT, the initrd is miniroot.lz, which is lzma format. Most of the program file does not have the magic for that.
       oldinitrd="$i"
   
@@ -600,7 +600,7 @@ install_SL(){
       #   -c --stdout       output to standard output
       #   -d --decompress   force decompression
       #   -z --compress     force compression
-      if [ -n "$(lzma --h 2>&1 | grep -iEw "\-so:")" ]; then
+      if [ -n "$(LC_ALL=C lzma --h 2>&1 | grep -iEw "\-so:")" ]; then
         uncompress_to_stdout="lzma d -so"
         compress_to_stdout="lzma e -so"
       else
@@ -608,7 +608,7 @@ install_SL(){
         compress_to_stdout="lzma -z -c"
       fi
       break
-    elif [ -n "$(file $i | grep -i "ASCII cpio archive")" ]; then
+    elif [ -n "$(LC_ALL=C file -Ls $i | grep -i "ASCII cpio archive")" ]; then
       oldinitrd="$i"
       break
     fi
